﻿
namespace System.Management.HyperV
{
    /// <summary>
    /// Indicates the current health of the element. This attribute expresses the health of this element but not necessarily that of its subcomponents. The possible values are 0 to 30, where 5 means the element is entirely healthy and 30 means the element is completely non-functional.
    /// </summary>
    /// <remarks>http://msdn.microsoft.com/en-us/library/aa387898(VS.85).aspx</remarks>
    public enum HealthStateOption : ushort
    {
        /// <summary>
        /// The implementation cannot report on HealthState at this time.
        /// </summary>
        Unknown = 0,
        /// <summary>
        /// The element is fully functional and is operating within normal operational parameters and without error.
        /// </summary>
        OK = 5,
        /// <summary>
        /// The element is in working order and all functionality is provided. However, the element is not working to the best of its abilities. For example, the element might not be operating at optimal performance or it might be reporting recoverable errors.
        /// </summary>
        DegradedOrWarning = 10,
        /// <summary>
        /// All functionality is available but some might be degraded.
        /// </summary>
        MinorFailure = 15,
        /// <summary>
        /// The element is failing. It is possible that some or all of the functionality of this component is degraded or not working.
        /// </summary>
        MajorFailure = 20,
        /// <summary>
        /// The element is non-functional and recovery might not be possible.
        /// </summary>
        CriticalFailure = 25,
        /// <summary>
        /// The element has completely failed, and recovery is not possible. All functionality provided by this element has been lost.
        /// </summary>
        NonRecoverableError = 30
    }
}
